abacusai.feature_group_refresh_export_config — AbacusAI documentation

# abacusai.feature_group_refresh_export_config

## Classes

`FeatureGroupRefreshExportConfig` | A Feature Group Refresh Export Config outlines the export configuration for a feature group.

## Module Contents

class abacusai.feature_group_refresh_export_config.FeatureGroupRefreshExportConfig(client, connectorType=None, location=None, exportFileFormat=None, additionalIdColumns=None, databaseFeatureMapping=None, externalConnectionId=None, idColumn=None, objectName=None, writeMode=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A Feature Group Refresh Export Config outlines the export configuration for a feature group.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - connectorType (str) – The type of connector the feature group is

    - location (str) – The file connector location of the feature group export

    - exportFileFormat (str) – The file format of the feature group export

    - additionalIdColumns (list) – Additional id columns to use for upsert operations

    - databaseFeatureMapping (dict) – The mapping of feature names to database columns

    - externalConnectionId (str) – The unique identifier of the external connection to write to

    - idColumn (str) – The column to use as the id column for upsert operations

    - objectName (str) – The name of the object to write to

    - writeMode (str) – The write mode to use for the export

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict